@@ -6,14 +6,13 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use 5.010;
 use utf8;
 use Modern::Perl;    ## no critic (UselessNoCritic,RequireExplicitPackage)
 
 package XML::Ant::BuildFile::Role::HasProjects;
 
 BEGIN {
-    $XML::Ant::BuildFile::Role::HasProjects::VERSION = '0.214';
+    $XML::Ant::BuildFile::Role::HasProjects::VERSION = '0.215';
 }
 
 # ABSTRACT: Compose a collection of Ant build file projects
@@ -100,7 +99,7 @@ XML::Ant::BuildFile::Role::HasProjects - Compose a collection of Ant build file
 
 =head1 VERSION
 
-version 0.214
+version 0.215
 
 =head1 SYNOPSIS
 
@@ -142,7 +141,7 @@ current C<working_copy> directory.
 
 You can find documentation for this module with the perldoc command.
 
-  perldoc XML::Ant::BuildFile
+  perldoc XML::Ant::BuildFile::Project
 
 =head2 Websites
 
@@ -155,17 +154,23 @@ in addition to those websites please use your favorite search engine to discover
 
 Search CPAN
 
+The default CPAN search engine, useful to view POD in HTML format.
+
 L<http://search.cpan.org/dist/XML-Ant-BuildFile>
 
 =item *
 
 RT: CPAN's Bug Tracker
 
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Ant-BuildFile>
 
 =item *
 
-AnnoCPAN: Annotated CPAN documentation
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annonations of Perl module documentation.
 
 L<http://annocpan.org/dist/XML-Ant-BuildFile>
 
@@ -173,32 +178,50 @@ L<http://annocpan.org/dist/XML-Ant-BuildFile>
 
 CPAN Ratings
 
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
 L<http://cpanratings.perl.org/d/XML-Ant-BuildFile>
 
 =item *
 
 CPAN Forum
 
+The CPAN Forum is a web forum for discussing Perl modules.
+
 L<http://cpanforum.com/dist/XML-Ant-BuildFile>
 
 =item *
 
-CPANTS Kwalitee
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
 L<http://cpants.perl.org/dist/overview/XML-Ant-BuildFile>
 
 =item *
 
-CPAN Testers Results
+CPAN Testers
 
-L<http://cpantesters.org/distro/X/XML-Ant-BuildFile.html>
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-Ant-BuildFile>
 
 =item *
 
 CPAN Testers Matrix
 
+The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+
 L<http://matrix.cpantesters.org/?dist=XML-Ant-BuildFile>
 
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::Ant::BuildFile::Project>
+
 =back
 
 =head2 Bugs / Feature Requests
